﻿using System;
using System.Linq;
using System.Windows;
using System.Windows.Input;
using Infragistics.Windows.Ribbon;
using System.Windows.Documents;
using System.Windows.Controls;
using System.Windows.Navigation;

namespace TestInfraAppMenu
{
	public partial class MainWindow
	{
		private System.Collections.Generic.List<string> m_MRU = new System.Collections.Generic.List<string>();

		public void InitMainWindow()
		{
			LoadMRU();
		}

		public void AppClose()
		{
			SaveMRU();
			this.Close();
		}

		public void ProjectOpen()
		{
			Microsoft.Win32.OpenFileDialog dlg = new Microsoft.Win32.OpenFileDialog();

			dlg.DefaultExt = ".*";
			dlg.Filter = "all Files (.*)|*.*";

			Nullable<bool> result = dlg.ShowDialog();
			if (result == true)
			{
				ProjectOpen(dlg.FileName);
			}
		}

		internal void ProjectOpen(string filename)
		{
			System.Diagnostics.Debug.WriteLine("Loading: " + filename);
			Mouse.OverrideCursor = Cursors.Wait;

			try
			{
				// project load

				UpdateMRU(filename);
				System.Diagnostics.Debug.WriteLine("Done loading");
			}
			catch (Exception e)
			{
				System.Diagnostics.Debug.WriteLine("Error during load: " + e);
				//throw;
			}
			finally
			{
				Mouse.OverrideCursor = null;
			}
		}

		// private methods

		private void LoadMRU()
		{
			m_MRU.Clear();
			Microsoft.Win32.RegistryKey key = Microsoft.Win32.Registry.CurrentUser.OpenSubKey("TestInfraAppMenu", false);
			if (key == null) key = Microsoft.Win32.Registry.CurrentUser.CreateSubKey("TestInfraAppMenu");
			int count = (int)key.GetValue("MRU.Count", 0);
			for (int i = 0; i < count; i++)
			{
				m_MRU.Add((string)key.GetValue("MRU.Item" + i));
			}
			UpdateMRU();
		}

		private void SaveMRU()
		{
			Microsoft.Win32.RegistryKey key = Microsoft.Win32.Registry.CurrentUser.OpenSubKey("TestInfraAppMenu", true);
			key.SetValue("MRU.Count", m_MRU.Count);
			for (int i = 0; i < m_MRU.Count; i++)
			{
				key.SetValue("MRU.Item" + i, m_MRU.ElementAt(i));
			}
		}

		private void UpdateMRU(string filename)
		{
			if (m_MRU.Contains(filename) == false)
			{
				m_MRU.Insert(0, filename);
			}
			else
			{
				m_MRU.Remove(filename);
				m_MRU.Insert(0, filename);
			}

			// limit to 10 entries
			if (m_MRU.Count > 10)
				m_MRU.RemoveAt(10);

			UpdateMRU();
		}

		private void UpdateMRU()
		{
			this.Ribbon.ApplicationMenu.RecentItems.Clear();

			for (int i = 0; i < m_MRU.Count; i++)
			{
				ButtonTool bt = new ButtonTool();
				bt.Click += new RoutedEventHandler(AppMenuMRU_Click);
				bt.Caption = m_MRU.ElementAt(i);
				this.Ribbon.ApplicationMenu.RecentItems.Add(bt);
			}
		}
	}
}
